@@ -4,43 +4,50 @@
 #'  \deqn{V_{new} = V_{old} + \eta_{+} \cdot (R - V_{old}), R > V_{old}}
 #'  \deqn{V_{new} = V_{old} + \eta_{-} \cdot (R - V_{old}), R < V_{old}}
 #' 
-#' @param params [vector] algorithm packages accept only one argument
+#' @param params [vector] 
+#' 
+#' algorithm packages accept only one argument
 #'
-#' @return [numeric] algorithm packages accept only one return
+#' @return loss [numeric] 
+#' 
+#' algorithm packages accept only one return
 #' 
 #' @examples
 #' \dontrun{
-#' RSTD <- function(params){
-#'
+#' RSTD <- function(params) {
 #'   res <- binaryRL::run_m(
 #'     data = data,
 #'     id = id,
 #'     eta = c(params[1], params[2]),
 #'     tau = c(params[3]),
+#'     priors = priors,
 #'     n_params = n_params,
 #'     n_trials = n_trials,
-#'     mode = mode
+#'     mode = mode,
+#'     policy = policy
 #'   )
 #'
 #'   assign(x = "binaryRL.res", value = res, envir = binaryRL.env)
-#'
-#'   switch(mode, "fit" = -res$ll, "simulate" = res, "replay" = res)
+#'   loss <- switch(EXPR = estimate, "MLE" = -res$ll, "MAP" = -res$lpo)
+#'   switch(EXPR = mode, "fit" = loss, "simulate" = res, "replay" = res)
 #' }
 #' }
 
 RSTD <- function(params){
   
   res <- binaryRL::run_m(
-    data = data,                   
+    data = data,
     id = id,                        
     eta = c(params[1], params[2]), 
     tau = c(params[3]),
+    priors = priors,
     n_params = n_params,                   
     n_trials = n_trials,
-    mode = mode
+    mode = mode,
+    policy = policy
   )
   
   assign(x = "binaryRL.res", value = res, envir = binaryRL.env)
-  
-  switch(mode, "fit" = -res$ll, "simulate" = res, "replay" = res)
+  loss <- switch(EXPR = estimate, "MLE" = -res$ll, "MAP" = -res$lpo)
+  switch(EXPR = mode, "fit" = loss, "simulate" = res, "replay" = res)
 }
